@@ -2,7 +2,6 @@ import os
 import sys
 import tempfile
 import subprocess
-import readline
 from typing import Dict
 
 from rich import print
@@ -120,9 +119,8 @@ def user_input(prompt="\nUser: ") -> str:
         lines.append(line)
         # Update the prompt using readline
         prompt = "\r" + " " * len(prompt) + "\r" + " .... "
-        readline.get_line_buffer()
     # Print a message indicating that the input has been submitted
-    msg = "\n".join(lines).strip()
+    msg = "\n\n".join(lines).strip()
     if not msg:
         printmd("**[Empty Input Skipped]**")
     return msg
